@@ -25,6 +25,7 @@
 #include <kapplication.h>
 #include <klocale.h>
 #include <kglobal.h>
+#include <kiconloader.h>
 
 #include "articleview.h"
 #include "global.h"
@@ -53,10 +54,14 @@ void ArticleViewItem::setEntry(const RegEntry &e)
 
 	setText(ARTICLE_COL_TITLE, e.lineStr(REG_LINE_TITLE));
 	setText(ARTICLE_COL_SUBTITLE, e.lineStr(REG_LINE_SUBTITLE));
-	if (e.magazine() == REG_MAGAZINE_CT)
+	if (e.magazine() == REG_MAGAZINE_CT) {
+//		setPixmap(ARTICLE_COL_MAGAZINE, UserIcon(QString::fromLatin1("ct_mini")));
 		setText(ARTICLE_COL_MAGAZINE, QString::fromLatin1("c't"));
-	else if (e.magazine() == REG_MAGAZINE_IX)
+	}
+	else if (e.magazine() == REG_MAGAZINE_IX) {
+//		setPixmap(ARTICLE_COL_MAGAZINE, UserIcon(QString::fromLatin1("ix_mini")));
 		setText(ARTICLE_COL_MAGAZINE, QString::fromLatin1("iX"));
+	}
 	s.sprintf("%d/%04d", e.edition(), e.year());
 	setText(ARTICLE_COL_EDITION, s);
 
