@@ -45,17 +45,17 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 
 	config = kapp->config();
 
-	setHelp("configure-help");
+	setHelp(QString::fromLatin1("configure-help"));
 	setIconListAllVisible(true);
 
 	/* Page 1: General */
-	page = addPage(i18n("General"), i18n("General Settings"), UserIcon("general"));
+	page = addPage(i18n("General"), i18n("General Settings"), UserIcon(QString::fromLatin1("general")));
 
-	vbox = new QVBoxLayout(page, 12);
+	vbox = new QVBoxLayout(page, spacingHint());
 
 	gb = new QGroupBox(i18n("User Interface"), page);
-	svbox = new QVBoxLayout(gb, 10);
-	svbox->addSpacing(8);
+	svbox = new QVBoxLayout(gb, spacingHint());
+	svbox->addSpacing(fontMetrics().height());
 
 	gen_tooltips = new QCheckBox(i18n("Show tooltips"), gb);
 	gen_tooltips->setMinimumSize(gen_tooltips->sizeHint());
@@ -69,9 +69,9 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 
 
 	/* Page 2: Search */
-	page = addPage(i18n("Search"), i18n("Search Settings"), UserIcon("search"));
+	page = addPage(i18n("Search"), i18n("Search Settings"), UserIcon(QString::fromLatin1("search")));
 
-	vbox = new QVBoxLayout(page, 12);
+	vbox = new QVBoxLayout(page, spacingHint());
 
 	grid = new QGridLayout(6, 3, spacingHint());
 	vbox->addLayout(grid);
@@ -175,7 +175,7 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	shbox = new QHBoxLayout(spacingHint());
 	svbox->addLayout(shbox);
 	shbox->addSpacing(19);
-	sea_min_threshold = new QLabel("0%", gb);
+	sea_min_threshold = new QLabel(QString::fromLatin1("0%"), gb);
 	sea_min_threshold->setFixedSize(sea_min_threshold->sizeHint());
 	sea_min_threshold->setEnabled(false);
 	shbox->addWidget(sea_min_threshold);
@@ -185,19 +185,62 @@ Configure::Configure(QWidget *parent, const char *name): KDialogBase(IconList, i
 	sea_threshold->setMinimumSize(sea_threshold->sizeHint());
 	sea_threshold->setEnabled(false);
 	shbox->addWidget(sea_threshold);
-	sea_max_threshold = new QLabel("100%", gb);
+	sea_max_threshold = new QLabel(QString::fromLatin1("100%"), gb);
 	sea_max_threshold->setFixedSize(sea_max_threshold->sizeHint());
 	sea_max_threshold->setEnabled(false);
 	shbox->addWidget(sea_max_threshold);
 
 	svbox->addStretch();
-
 	svbox->activate();
 
 	hbox->addWidget(gb);
 
+	vbox->addStretch(1);
+	vbox->activate();
 
-	config->setGroup(ID_PREF_GROUP_GENERAL);
+
+	/* Page 3: Network */
+	page = addPage(i18n("Network"), i18n("Network Settings"), UserIcon(QString::fromLatin1("network")));
+
+	vbox = new QVBoxLayout(page, spacingHint());
+
+	gb = new QGroupBox(i18n("Register File FTP Directory URLs"), page);
+
+	svbox = new QVBoxLayout(gb, spacingHint());
+	svbox->addSpacing(fontMetrics().height());
+
+	grid = new QGridLayout(2, 2, spacingHint());
+	svbox->addLayout(grid);
+
+	label = new QLabel(i18n("c'&t Magazine:"), gb);
+	label->setMinimumSize(label->sizeHint());
+	grid->addWidget(label, 0, 0);
+
+	net_cturl = new QLineEdit(gb);
+	label->setBuddy(net_cturl);
+	net_cturl->setMinimumSize(net_cturl->sizeHint());
+	grid->addWidget(net_cturl, 0, 1);
+
+	label = new QLabel(i18n("&iX Magazine:"), gb);
+	label->setMinimumSize(label->sizeHint());
+	grid->addWidget(label, 1, 0);
+
+	net_ixurl = new QLineEdit(gb);
+	label->setBuddy(net_ixurl);
+	net_ixurl->setMinimumSize(net_ixurl->sizeHint());
+	grid->addWidget(net_ixurl, 1, 1);
+
+	grid->setColStretch(1, 1);
+
+	svbox->activate();
+
+	vbox->addWidget(gb);
+
+	vbox->addStretch(1);
+	vbox->activate();
+
+
+	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_GENERAL));
 	if (config->readBoolEntry(ID_PREF_GEN_TOOLTIPS, PREF_GEN_TOOLTIPS)) {
 		QToolTip::add(gen_tooltips, i18n("Show tooltips in dialogs"));
 	}
@@ -216,25 +259,27 @@ Configure::~Configure()
 void Configure::slotDefault()
 {
 	gen_tooltips->setChecked(PREF_GEN_TOOLTIPS);
-	sea_bywords->clear();
-	sea_authors->clear();
-	sea_editors->clear();
-	sea_editions->clear();
-	sea_years->clear();
+	sea_bywords->setText(QString::fromLatin1(PREF_SEA_BYWORDS));
+	sea_authors->setText(QString::fromLatin1(PREF_SEA_AUTHORS));
+	sea_editors->setText(QString::fromLatin1(PREF_SEA_EDITORS));
+	sea_editions->setText(QString::fromLatin1(PREF_SEA_EDITIONS));
+	sea_years->setText(QString::fromLatin1(PREF_SEA_YEARS));
 	sea_ctmag->setChecked(PREF_SEA_CTMAG);
 	sea_ixmag->setChecked(PREF_SEA_IXMAG);
 	sea_case_sensitive->setChecked(PREF_SEA_CASE);
 	sea_fuzzy->setChecked(PREF_SEA_FUZZY);
 	sea_threshold->setValue(PREF_SEA_THRESHOLD);
+	net_cturl->setText(PREF_NET_CTURL);
+	net_ixurl->setText(PREF_NET_IXURL);
 }
 
 
 void Configure::slotApply()
 {
-	config->setGroup(ID_PREF_GROUP_GENERAL);
+	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_GENERAL));
 	config->writeEntry(ID_PREF_GEN_TOOLTIPS, gen_tooltips->isChecked());
 
-	config->setGroup(ID_PREF_GROUP_SEARCH);
+	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_SEARCH));
 	config->writeEntry(ID_PREF_SEA_BYWORDS, sea_bywords->text());
 	config->writeEntry(ID_PREF_SEA_AUTHORS, sea_authors->text());
 	config->writeEntry(ID_PREF_SEA_EDITORS, sea_editors->text());
@@ -246,6 +291,10 @@ void Configure::slotApply()
 	config->writeEntry(ID_PREF_SEA_FUZZY, sea_fuzzy->isChecked());
 	config->writeEntry(ID_PREF_SEA_THRESHOLD, sea_threshold->value());
 
+	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_NETWORK));
+	config->writeEntry(ID_PREF_NET_CTURL, net_cturl->text());
+	config->writeEntry(ID_PREF_NET_IXURL, net_ixurl->text());
+
 	config->sync();
 }
 
@@ -260,20 +309,24 @@ void Configure::accept()
 
 void Configure::reset()
 {
-	config->setGroup(ID_PREF_GROUP_GENERAL);
+	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_GENERAL));
 	gen_tooltips->setChecked(config->readBoolEntry(ID_PREF_GEN_TOOLTIPS, PREF_GEN_TOOLTIPS));
 
-	config->setGroup(ID_PREF_GROUP_SEARCH);
-	sea_bywords->setText(config->readEntry(ID_PREF_SEA_BYWORDS, ""));
-	sea_authors->setText(config->readEntry(ID_PREF_SEA_AUTHORS, ""));
-	sea_editors->setText(config->readEntry(ID_PREF_SEA_EDITORS, ""));
-	sea_editions->setText(config->readEntry(ID_PREF_SEA_EDITIONS, ""));
-	sea_years->setText(config->readEntry(ID_PREF_SEA_YEARS, ""));
+	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_SEARCH));
+	sea_bywords->setText(config->readEntry(ID_PREF_SEA_BYWORDS, QString::fromLatin1(PREF_SEA_BYWORDS)));
+	sea_authors->setText(config->readEntry(ID_PREF_SEA_AUTHORS, QString::fromLatin1(PREF_SEA_AUTHORS)));
+	sea_editors->setText(config->readEntry(ID_PREF_SEA_EDITORS, QString::fromLatin1(PREF_SEA_EDITORS)));
+	sea_editions->setText(config->readEntry(ID_PREF_SEA_EDITIONS, QString::fromLatin1(PREF_SEA_EDITIONS)));
+	sea_years->setText(config->readEntry(ID_PREF_SEA_YEARS, QString::fromLatin1(PREF_SEA_YEARS)));
 	sea_ctmag->setChecked(config->readBoolEntry(ID_PREF_SEA_CTMAG, PREF_SEA_CTMAG));
 	sea_ixmag->setChecked(config->readBoolEntry(ID_PREF_SEA_IXMAG, PREF_SEA_IXMAG));
 	sea_case_sensitive->setChecked(config->readBoolEntry(ID_PREF_SEA_CASE, PREF_SEA_CASE));
 	sea_fuzzy->setChecked(config->readBoolEntry(ID_PREF_SEA_FUZZY, PREF_SEA_FUZZY));
 	sea_threshold->setValue(config->readNumEntry(ID_PREF_SEA_THRESHOLD, PREF_SEA_THRESHOLD));
+
+	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_NETWORK));
+	net_cturl->setText(config->readEntry(ID_PREF_NET_CTURL, QString::fromLatin1(PREF_NET_CTURL)));
+	net_ixurl->setText(config->readEntry(ID_PREF_NET_IXURL, QString::fromLatin1(PREF_NET_IXURL)));
 }
 
 
