@@ -30,6 +30,7 @@
 #include <qstring.h>
 
 #define REGISTER_FILE						"content.reg"
+#define DOWNLOAD_DIR						"download"
 
 #define ID_PREF_GROUP_GENERAL		"General"
 #define ID_PREF_GEN_TOOLTIPS		"ToolTips"
@@ -37,10 +38,15 @@
 
 #define ID_PREF_GROUP_SEARCH		"Search"
 #define ID_PREF_SEA_BYWORDS			"Bywords"
+#define PREF_SEA_BYWORDS				""
 #define ID_PREF_SEA_AUTHORS			"Authors"
+#define PREF_SEA_AUTHORS				""
 #define ID_PREF_SEA_EDITORS			"Editors"
+#define PREF_SEA_EDITORS				""
 #define ID_PREF_SEA_EDITIONS		"Editions"
+#define PREF_SEA_EDITIONS				""
 #define ID_PREF_SEA_YEARS				"Years"
+#define PREF_SEA_YEARS					""
 #define ID_PREF_SEA_CTMAG				"ct"
 #define PREF_SEA_CTMAG					true
 #define ID_PREF_SEA_IXMAG				"ix"
@@ -52,6 +58,13 @@
 #define ID_PREF_SEA_THRESHOLD		"Threshold"
 #define PREF_SEA_THRESHOLD			100
 
+#define ID_PREF_GROUP_NETWORK		"Network"
+#define ID_PREF_NET_CTURL				"ctFTPDirectory"
+#define PREF_NET_CTURL					"ftp://ftp.heise.de/pub/ct/inhalt/"
+#define ID_PREF_NET_IXURL				"ixFTPDirectory"
+#define PREF_NET_IXURL					"ftp://ftp.heise.de/pub/ix/inhalt/"
+
+
 
 #define ID_HELP_CONTENTS           1002
 #define ID_HELP_ABOUT              1003
