@@ -172,13 +172,14 @@ void KHeiseView::search(const RegMask &mask)
 	progress.setLabelText(i18n("Searching..."));
 	progress.setTotalSteps(file.size());
 
-//	articleview->setUpdatesEnabled(false);
+	kapp->processEvents();
+	articleview->setUpdatesEnabled(false);
 	while (file.readEntry(&entry)) {
 		if (mask.matches(entry)) {
 			articleview->addEntry(entry);
 			count++;
 		}
-		if (++i == 200) {
+		if (++i == 250) {
 			progress.setProgress(file.at());
 			kapp->processEvents();
 			if (progress.wasCancelled())
@@ -186,9 +187,9 @@ void KHeiseView::search(const RegMask &mask)
 			i = 0;
 		}
 	}
+	articleview->setUpdatesEnabled(true);
+	articleview->triggerUpdate();
 	kapp->processEvents();
-//	articleview->setUpdatesEnabled(true);
-//	articleview->repaint();
 	file.close();
 
 	emit items(count);
