@@ -115,14 +115,14 @@ void RegSearchList::setKeyWords(const QString &text)
 			while (e < l && input.at(e) != ' ')
 				e++;
 		}
-		
+
 		if (inc)
 			m_require.append(input.mid(s, e - s));
 		else if (exc)
 			m_exclude.append(input.mid(s, e - s));
 		else
 			m_include.append(input.mid(s, e - s));
-		
+
 		s = e + 1;
 	}
 }
@@ -255,7 +255,7 @@ QCString RegEntry::lineStr(int num) const
 
 	qstrcpy((char *)buff, m_lines[num]);
 	l = qstrlen((char *)buff);
-	
+
 	if ((l) && buff[l-1] == '\x0a')
 		l--;
 	if ((l) && buff[l-1] == '\x0d')
@@ -280,14 +280,14 @@ int RegEntry::edition() const
 	return atoi(m_lines[REG_LINE_EDITION]);
 }
 
-	
+
 unsigned char RegEntry::magazine() const
 {
 	if (*m_lines[REG_LINE_MAGYEAR] == 'c')
 		return REG_MAGAZINE_CT;
 	if (*m_lines[REG_LINE_MAGYEAR] == 'i')
 		return REG_MAGAZINE_IX;
-		
+
 	return REG_MAGAZINE_NONE;
 }
 
@@ -310,7 +310,7 @@ bool RegEntry::verify() const
 		if ((len < 2) || (m_lines[i][len-2] != 0x0d) || (m_lines[i][len-1] != 0x0a))
 			return false;
 	}
-	
+
 	// - Does line 5 (page number) only contain blanks and digits?
 	if (qstrlen(m_lines[4]) != 5)
 		return false;
@@ -447,7 +447,7 @@ bool RegFile::scanEntries()
 {
 	RegEntry entry;
 	int edition;
-		
+
 	ct_first_ed = 999999;
 	ct_last_ed = 0;
 	ct_articles = 0;
@@ -499,18 +499,6 @@ int RegFile::firstEdition(unsigned char mag) const
 }
 
 
-int RegFile::lastEdition(unsigned char mag) const
-{
-	return (mag & REG_MAGAZINE_CT) ? ct_last_ed : ix_last_ed;
-}
-
-
-int RegFile::articles(unsigned char mag) const
-{
-	return (mag & REG_MAGAZINE_CT) ? ct_articles : ix_articles;
-}
-
-
 bool RegFile::containsEditions(unsigned char mag, const RegNumList &editions) const
 {
 	RegNumList::ConstIterator it;
