@@ -21,12 +21,15 @@
  */
 
 #include <qlayout.h>
-#include <qpushbutton.h>
 #include <qsize.h>
 #include <qgroupbox.h>
+#include <qiconset.h>
 
 #include <klocale.h>
 #include <kapplication.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
+#include <kiconloader.h>
 
 #include "global.h"
 #include "searchdlg.h"
@@ -38,7 +41,7 @@ SearchDlg::SearchDlg(QWidget *parent, const char *name): KDialog(parent, name, f
 	QGridLayout *grid;
 	QLabel *label;
 	QGroupBox *gbox;
-	QPushButton *bhelp, *bdefault, *bsearch, *bclose;
+	KPushButton *bhelp, *bdefault, *bsearch, *bclose;
 	QSize size;
 
 	config = kapp->config();
@@ -83,7 +86,7 @@ SearchDlg::SearchDlg(QWidget *parent, const char *name): KDialog(parent, name, f
 	label->setBuddy(editions);
 	editions->setMinimumSize(editions->sizeHint());
 	grid->addWidget(editions, 2, 3);
-	
+
 	label = new QLabel(i18n("&Years:"), this);
 	label->setFixedSize(label->sizeHint());
 	grid->addWidget(label, 2, 4, AlignVCenter | AlignRight);
@@ -126,7 +129,7 @@ SearchDlg::SearchDlg(QWidget *parent, const char *name): KDialog(parent, name, f
 	hbox->addWidget(gbox);
 
 	gbox = new QGroupBox(i18n("Options"), this);
-	
+
 	svbox = new QVBoxLayout(gbox, spacingHint());
 	svbox->addSpacing(fontMetrics().height());
 
@@ -136,7 +139,7 @@ SearchDlg::SearchDlg(QWidget *parent, const char *name): KDialog(parent, name, f
 	case_sensitive->setFixedSize(case_sensitive->sizeHint());
 	shbox->addWidget(case_sensitive);
 	shbox->addStretch();
-	
+
 	shbox = new QHBoxLayout(spacingHint());
 	svbox->addLayout(shbox);
 	fuzzy = new QCheckBox(i18n("&Fuzzy"), gbox);
@@ -147,7 +150,7 @@ SearchDlg::SearchDlg(QWidget *parent, const char *name): KDialog(parent, name, f
 	shbox = new QHBoxLayout(spacingHint());
 	svbox->addLayout(shbox);
 	shbox->addSpacing(19);
-	min_threshold = new QLabel("0%", gbox);
+	min_threshold = new QLabel(QString::fromLatin1("0%"), gbox);
 	min_threshold->setFixedSize(min_threshold->sizeHint());
 	min_threshold->setEnabled(false);
 	shbox->addWidget(min_threshold);
@@ -157,39 +160,41 @@ SearchDlg::SearchDlg(QWidget *parent, const char *name): KDialog(parent, name, f
 	threshold->setMinimumSize(threshold->sizeHint());
 	threshold->setEnabled(false);
 	shbox->addWidget(threshold);
-	max_threshold = new QLabel("100%", gbox);
+	max_threshold = new QLabel(QString::fromLatin1("100%"), gbox);
 	max_threshold->setFixedSize(max_threshold->sizeHint());
 	max_threshold->setEnabled(false);
 	shbox->addWidget(max_threshold);
 
 	svbox->addStretch();
-	
+
 	svbox->activate();
 
 	hbox->addWidget(gbox);
-	
+
 	vbox->addStretch();
 
 	hbox = new QHBoxLayout(spacingHint());
 	vbox->addLayout(hbox);
 
-	bhelp = new QPushButton(i18n("&Help"), this);
-	bdefault = new QPushButton(i18n("&Default"), this);
-	bdefault->setFixedSize(bdefault->sizeHint());
-	bsearch = new QPushButton(i18n("&Search"), this);
+	bhelp = new KPushButton(KStdGuiItem::help(), this);
+	bdefault = new KPushButton(KStdGuiItem::defaults(), this);
+	bdefault->setFixedWidth(bdefault->sizeHint().width());
+	bsearch = new KPushButton(SmallIconSet(QString::fromLatin1("find")), i18n("&Search"), this);
 	bsearch->setDefault(true);
-	bclose = new QPushButton(i18n("&Close"), this);
-	bclose->setFixedSize(bclose->sizeHint());
+	bclose = new KPushButton(KStdGuiItem::close(), this);
+	bclose->setFixedWidth(bclose->sizeHint().width());
 
 	size = bhelp->sizeHint().expandedTo(bsearch->sizeHint());
+	bdefault->setFixedHeight(size.height());
 	bhelp->setFixedSize(size);
 	bsearch->setFixedSize(size);
+	bclose->setFixedHeight(size.height());
 
-	hbox->addWidget(bhelp);	
-	hbox->addWidget(bdefault);	
+	hbox->addWidget(bhelp);
+	hbox->addWidget(bdefault);
 	hbox->addStretch();
-	hbox->addWidget(bsearch);	
-	hbox->addWidget(bclose);	
+	hbox->addWidget(bsearch);
+	hbox->addWidget(bclose);
 
 	vbox->activate();
 
@@ -220,18 +225,18 @@ void SearchDlg::slotFuzzyToggled(bool on)
 
 void SearchDlg::slotHelp()
 {
-	kapp->invokeHelp("search-help");
+	kapp->invokeHelp(QString::fromLatin1("search-help"));
 }
 
 
 void SearchDlg::slotDefault()
 {
-	config->setGroup(ID_PREF_GROUP_SEARCH);
-	bywords->setText(config->readEntry(ID_PREF_SEA_BYWORDS, ""));
-	authors->setText(config->readEntry(ID_PREF_SEA_AUTHORS, ""));
-	editors->setText(config->readEntry(ID_PREF_SEA_EDITORS, ""));
-	editions->setText(config->readEntry(ID_PREF_SEA_EDITIONS, ""));
-	years->setText(config->readEntry(ID_PREF_SEA_YEARS, ""));
+	config->setGroup(QString::fromLatin1(ID_PREF_GROUP_SEARCH));
+	bywords->setText(config->readEntry(ID_PREF_SEA_BYWORDS, QString::fromLatin1(PREF_SEA_BYWORDS)));
+	authors->setText(config->readEntry(ID_PREF_SEA_AUTHORS, QString::fromLatin1(PREF_SEA_AUTHORS)));
+	editors->setText(config->readEntry(ID_PREF_SEA_EDITORS, QString::fromLatin1(PREF_SEA_EDITORS)));
+	editions->setText(config->readEntry(ID_PREF_SEA_EDITIONS, QString::fromLatin1(PREF_SEA_EDITIONS)));
+	years->setText(config->readEntry(ID_PREF_SEA_YEARS, QString::fromLatin1(PREF_SEA_YEARS)));
 	ctmag->setChecked(config->readBoolEntry(ID_PREF_SEA_CTMAG, PREF_SEA_CTMAG));
 	ixmag->setChecked(config->readBoolEntry(ID_PREF_SEA_IXMAG, PREF_SEA_IXMAG));
 	case_sensitive->setChecked(config->readBoolEntry(ID_PREF_SEA_CASE, PREF_SEA_CASE));
